cgexplore.analysis
==================

.. automodule:: cgexplore.analysis

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      GeomMeasure
      ShapeMeasure
   
   


   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      known_shape_vectors
   
   

   
   
   



